Enum cw_storage_plus::Bound
source · pub enum Bound<'a, K: PrimaryKey<'a>> {
Inclusive((K, PhantomData<&'a bool>)),
Exclusive((K, PhantomData<&'a bool>)),
InclusiveRaw(Vec<u8>),
ExclusiveRaw(Vec<u8>),
}Expand description
Bound is used to define the two ends of a range.
None means that we don’t limit that side of the range at all.
Inclusive means we use the given value as a limit and include anything at that exact key.
Exclusive means we use the given value as a limit and exclude anything at that exact key.
Variants
Inclusive((K, PhantomData<&'a bool>))
Exclusive((K, PhantomData<&'a bool>))
InclusiveRaw(Vec<u8>)
ExclusiveRaw(Vec<u8>)
Implementations