Enum cw_storage_plus::RawBound
source · pub enum RawBound {
Inclusive(Vec<u8>),
Exclusive(Vec<u8>),
}Expand description
RawBound is used to define the two ends of a range, more explicit than Option<u8>.
None means that we don’t limit that side of the range at all.
Inclusive means we use the given bytes as a limit and include anything at that exact key.
Exclusive means we use the given bytes as a limit and exclude anything at that exact key.
See Bound for a type safe way to build these bounds.
Variants