Deque

Struct Deque 

pub struct Deque<T> { /* private fields */ }
A deque stores multiple items at the given key. It provides efficient FIFO and LIFO access, as well as direct index access.

It has a maximum capacity of u32::MAX - 1. Make sure to never exceed that number when using this type. If you do, the methods won’t work as intended anymore.

Implementations

Source

impl<T> Deque<T>

pub const fn new(prefix: &'static str) -> Self

Creates a new Deque with the given storage key. This is a constant function only suitable when you have a prefix in the form of a static string slice.

pub fn new_dyn(prefix: impl Into<Namespace>) -> Self

Creates a new Deque with the given storage key. Use this if you might need to handle a dynamic string. Otherwise, you should probably prefer Deque::new.

Source

impl<T: Serialize + DeserializeOwned> Deque<T>

pub fn push_back(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>

Adds the given value to the end of the deque

pub fn push_front(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>

Adds the given value to the front of the deque

pub fn pop_back(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>

Removes the last element of the deque and returns it

pub fn pop_front(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>

Removes the first element of the deque and returns it

pub fn front(&self, storage: &dyn Storage) -> StdResult<Option<T>>

Returns the first element of the deque without removing it

pub fn back(&self, storage: &dyn Storage) -> StdResult<Option<T>>

Returns the last element of the deque without removing it

pub fn len(&self, storage: &dyn Storage) -> StdResult<u32>

Gets the length of the deque.

pub fn is_empty(&self, storage: &dyn Storage) -> StdResult<bool>

Returns true if the deque contains no elements.

pub fn get(&self, storage: &dyn Storage, pos: u32) -> StdResult<Option<T>>

Returns the value at the given position in the queue or None if the index is out of bounds

pub fn set( &self, storage: &mut dyn Storage, pos: u32, value: &T, ) -> StdResult<()>

Sets the value at the given position in the queue. Returns [StdError::NotFound] if index is out of bounds

Source

impl<T: Serialize + DeserializeOwned> Deque<T>

pub fn iter<'a>( &'a self, storage: &'a dyn Storage, ) -> StdResult<DequeIter<'a, T>>