pub struct Deque<T> { /* private fields */ }Expand description
A deque stores multiple items at the given key. It provides efficient FIFO and LIFO access, as well as direct index access.
It has a maximum capacity of u32::MAX - 1. Make sure to never exceed that number when using this type.
If you do, the methods won’t work as intended anymore.
Implementations
Sourceimpl<T> Deque<T>
impl<T> Deque<T>
Sourceimpl<T: Serialize + DeserializeOwned> Deque<T>
impl<T: Serialize + DeserializeOwned> Deque<T>
Sourcepub fn push_back(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>
pub fn push_back(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>
Adds the given value to the end of the deque
Sourcepub fn push_front(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>
pub fn push_front(&self, storage: &mut dyn Storage, value: &T) -> StdResult<()>
Adds the given value to the front of the deque
Sourcepub fn pop_back(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>
pub fn pop_back(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>
Removes the last element of the deque and returns it
Sourcepub fn pop_front(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>
pub fn pop_front(&self, storage: &mut dyn Storage) -> StdResult<Option<T>>
Removes the first element of the deque and returns it
Sourcepub fn front(&self, storage: &dyn Storage) -> StdResult<Option<T>>
pub fn front(&self, storage: &dyn Storage) -> StdResult<Option<T>>
Returns the first element of the deque without removing it
Sourcepub fn back(&self, storage: &dyn Storage) -> StdResult<Option<T>>
pub fn back(&self, storage: &dyn Storage) -> StdResult<Option<T>>
Returns the last element of the deque without removing it
Sourcepub fn is_empty(&self, storage: &dyn Storage) -> StdResult<bool>
pub fn is_empty(&self, storage: &dyn Storage) -> StdResult<bool>
Returns true if the deque contains no elements.